@@ -16,7 +16,8 @@ XPtr<DbConnectionPtr> connection_create(
   const Nullable<std::string>& ssl_cert,
   const Nullable<std::string>& ssl_ca,
   const Nullable<std::string>& ssl_capath,
-  const Nullable<std::string>& ssl_cipher
+  const Nullable<std::string>& ssl_cipher,
+  int timeout
 ) {
   LOG_VERBOSE;
 
@@ -24,7 +25,7 @@ XPtr<DbConnectionPtr> connection_create(
   try {
     pConnPtr->connect(
       host, user, password, db, port, unix_socket, client_flag, groups, default_file,
-      ssl_key, ssl_cert, ssl_ca, ssl_capath, ssl_cipher
+      ssl_key, ssl_cert, ssl_ca, ssl_capath, ssl_cipher, timeout
     );
   } catch (...) {
     delete pConnPtr;
