@@ -1,7 +1,11 @@
 DBItest::make_context(
   MariaDB(),
-  list(dbname = "test"),
+  list(
+    dbname = "test",
+    load_data_local_infile = (Sys.getenv("RMARIADB_LOAD_DATA_LOCAL_INFILE") != "")
+  ),
   tweaks = DBItest::tweaks(
+    dbitest_version = "1.7.2",
     constructor_relax_args = TRUE,
     placeholder_pattern = "?",
     logical_return = function(x) as.integer(x),
@@ -13,10 +17,12 @@ DBItest::make_context(
     "data_logical",                               # not an error: cannot cast to logical
     "data_raw",                                   # not an error: can't cast to blob type
 
-    # bad tests
+    # Fails on Ubuntu 18.04:
     "list_objects_features",
-    "append_roundtrip_timestamp",
-    "roundtrip_timestamp",
+
+    # bad tests
+    if (.Platform$OS.type == "windows" && .Platform$r_arch == "i386") "append_roundtrip_timestamp",
+    if (.Platform$OS.type == "windows" && .Platform$r_arch == "i386") "roundtrip_timestamp",
 
     NULL
   )
